@@ -1,4 +1,5 @@
 from patience.action import Action
+from patience.structures import ActionException
 
 
 class Develop(Action):
@@ -6,9 +7,12 @@ class Develop(Action):
     def __init__(self): 
         Action.__init__(self, parallel=False, any_order=False)
 
-    def single_action_starting(self, resource): pass
+    def single_action_starting(self, resource):  # @UnusedVariable
+        print 'ciao' 
+        pass
 
-    def single_action_result_display(self, resource, result): pass
+    def single_action_result_display(self, resource, result): 
+        pass
     
     def single_action(self, r):
         if r.is_downloaded():
